import type { Requests, Responses } from '@/dto';
import { post, post_token } from './base';

export const auth_login = (
	username: string,
	password: string,
	otp?: string
): Promise<Responses.Login | Responses.Success | Responses.Error> =>
	post<Requests.Login>('/api/auth/login', {
		username: username,
		password: password,
		otp: otp
	});

export const auth_signup = (
	username: string,
	password: string
): Promise<Responses.Success | Responses.Error> =>
	post<Requests.SignUp>('/api/auth/signup', {
		username: username,
		password: password
	});

export const send_recovery_key = (
	username: string
): Promise<Responses.Success | Responses.Error> =>
	post<Requests.SendRecoveryKey>('/api/auth/send_key', {
		username: username
	});

export const reset_password = (
	key: string,
	password: string
): Promise<Responses.Success | Responses.Error> =>
	post<Requests.ResetPassword>('/api/auth/reset', {
		key: key,
		password: password
	});

export const refresh_token = (
	token: string
): Promise<Responses.Login | Responses.Error> =>
	post_token('/api/auth/refresh', {}, token);

export const change_password = (
	oldPw: string,
	newPw: string,
	token: string
): Promise<Responses.Success | Responses.Error> =>
	post_token<Requests.ChangePassword>(
		'/api/auth/change_password',
		{
			oldPassword: oldPw,
			newPassword: newPw
		},
		token
	);

export const logout_all = (
	token: string
): Promise<Responses.Success | Responses.Error> =>
	post_token('/api/auth/logout_all', {}, token);

export function tfa_setup(
	mail: false,
	token: string
): Promise<Responses.RequestsTotpTfa | Responses.Error>;
export function tfa_setup(
	mail: true,
	token: string
): Promise<Responses.Success | Responses.Error>;
export function tfa_setup(
	mail: boolean,
	token: string
): Promise<Responses.Success | Responses.RequestsTotpTfa | Responses.Error> {
	return post_token<Requests.TfaSetup>(
		'/api/auth/2fa/setup',
		{
			mail
		},
		token
	);
}

export const tfa_complete = (
	mail: boolean,
	code: string,
	token: string
): Promise<Responses.Success | Responses.Error> =>
	post_token<Requests.TfaComplete>(
		'/api/auth/2fa/complete',
		{
			mail,
			code
		},
		token
	);

export const tfa_disable = (
	token: string
): Promise<Responses.Success | Responses.Error> =>
	post_token('/api/auth/2fa/disable', {}, token);
